@@ -1,8 +1,9 @@
-#ifndef BUTTON_EDIT_H
-#define BUTTON_EDIT_H
+#ifndef QJOYPAD_BUTTON_EDIT_H
+#define QJOYPAD_BUTTON_EDIT_H
 
 #include <QPushButton>
 #include <QCheckBox>
+#include <QDialogButtonBox>
 
 //we need to edit a Button
 #include "button.h"
@@ -20,10 +21,8 @@ class ButtonEdit : public QDialog {
 		void accept();
 	protected:
 		Button *button;
-		KeyButton *BKKey;
-		QPushButton *BKey, *BMouse, *BOkay, *BCancel;
-		QPushButton **BMKey;
-		QCheckBox *CSticky, *CRapid;
+		KeyButton *btnKey;
+		QCheckBox *chkSticky, *chkRapid;
 };
 
 
