@@ -1,5 +1,5 @@
-#ifndef JCONST_H
-#define JCONST_H
+#ifndef QJOYPAD_CONSTANT_H
+#define QJOYPAD_CONSTANT_H
 
 //How many cycles there are per click.
 #define FREQ 10
@@ -17,7 +17,7 @@
 #define JOYMIN -32767
 
 //maximum number of defined keys
-#define MAXKEY 122
+#define MAXKEY 255
 
 //fastest the mouse can go. Completely arbitrary.
 #define MAXMOUSESPEED 5000
@@ -25,8 +25,4 @@
 #define SENSITIVITY_MIN	1e-8F
 #define SENSITIVITY_MAX	1e+8F
 
-#define NAME "QJoyPad 4.1"
-
-#define MOUSE_OFFSET 400
-
 #endif
