@@ -1,6 +1,7 @@
-#ifndef LAYOUT_EDIT_H
-#define LAYOUT_EDIT_H
+#ifndef QJOYPAD_LAYOUT_EDIT_H
+#define QJOYPAD_LAYOUT_EDIT_H
 
+#include <QScrollArea>
 #include <QStackedWidget>
 
 //for the tab list of joypads
@@ -8,8 +9,6 @@
 //this is a front end for the non-GUI LayoutManager
 class LayoutEdit;
 #include "layout.h"
-//so we can see the available devices
-#include "device.h"
 //so we can use the LayoutEditer to edit key layouts  :)
 #include "joypadw.h"
 
@@ -18,9 +17,9 @@ class LayoutManager;
 class LayoutEdit : public QWidget {
 	Q_OBJECT
 	public:
-		LayoutEdit( LayoutManager* l );
+        LayoutEdit( LayoutManager* l );
 		//swap to a new layout
-		void setLayout(QString layout);
+        void setLayout(const QString& layout);
 		//update the list of available layouts
 		void updateLayoutList();
         void updateJoypadWidgets();
@@ -28,16 +27,18 @@ class LayoutEdit : public QWidget {
 		void focusStateChanged(bool);
     public slots:
         void appFocusChanged(QWidget *old, QWidget *now);
+    private slots:
+        void load(int index);
 	protected:
 		//the layout manager this represents
-		LayoutManager* lm;		
-		virtual void closeEvent(QCloseEvent *event);
+        LayoutManager* lm;
 		//parts of the dialog:
-		QVBoxLayout *LMain;
-		QStackedWidget *PadStack;
-		FlashRadioArray *JoyButtons;
-		QComboBox* CLayouts;
-		QPushButton	*BAdd, *BRem, *BUpd, *BRev;
+        QVBoxLayout *mainLayout;
+        QScrollArea *padScroll;
+        QStackedWidget *padStack;
+        FlashRadioArray *joyButtons;
+        QComboBox* cmbLayouts;
+        QPushButton *btnAdd, *btnRem, *btnUpd, *btnRev, *btnExport, *btnImport, *btnRename;
 };
 
 #endif
